==> prettier-3.1.1.tar.gz: prettier-3.1.1/src/language-html/print/angular-control-flow-block.js <==
import {
  group,
  hardline,
  softline,
  line,
  indent,
  join,
} from "../../document/builders.js";
import { printChildren } from "./children.js";
import ANGULAR_CONTROL_FLOW_BLOCK_SETTINGS from "./angular-control-flow-block-settings.evaluate.js";

function printAngularControlFlowBlock(path, options, print) {
  const { node } = path;
  const docs = [];

  if (isPreviousBlockUnClosed(path)) {
    docs.push("} ");
  }

  docs.push("@", node.name);

  if (node.parameters) {
    docs.push(" (", group(print("parameters")), ")");
  }

  docs.push(" {");

  const shouldPrintCloseBracket = shouldCloseBlock(node);
  if (node.children.length > 0) {
    node.firstChild.hasLeadingSpaces = true;
    node.lastChild.hasTrailingSpaces = true;
    docs.push(indent([hardline, printChildren(path, options, print)]));
    if (shouldPrintCloseBracket) {
      docs.push(hardline, "}");
    }
  } else if (shouldPrintCloseBracket) {
    docs.push("}");
  }

  return group(docs, { shouldBreak: true });
}

function shouldCloseBlock(node) {
  return !(
    node.next?.type === "angularControlFlowBlock" &&
    ANGULAR_CONTROL_FLOW_BLOCK_SETTINGS.get(node.name)?.has(node.next.name)
  );
}

function isPreviousBlockUnClosed(path) {
  const { previous } = path;
  return (
    previous?.type === "angularControlFlowBlock" &&
    !shouldCloseBlock(path.previous)
  );
}

function printAngularControlFlowBlockParameters(path, options, print) {
  return [
    indent([softline, join([";", line], path.map(print, "children"))]),
    softline,
  ];
}

export { printAngularControlFlowBlock, printAngularControlFlowBlockParameters };

==> prettier-3.5.0.tar.gz: prettier-3.5.0/src/language-html/print/angular-control-flow-block.js <==
import {
  group,
  hardline,
  indent,
  join,
  line,
  softline,
} from "../../document/builders.js";
import { hasPrettierIgnore } from "../utils/index.js";
import ANGULAR_CONTROL_FLOW_BLOCK_SETTINGS from "./angular-control-flow-block-settings.evaluate.js";
import { printChildren } from "./children.js";

function printAngularControlFlowBlock(path, options, print) {
  const { node } = path;
  const docs = [];

  if (isPreviousBlockUnClosed(path)) {
    docs.push("} ");
  }

  docs.push("@", node.name);

  if (node.parameters) {
    docs.push(" (", group(print("parameters")), ")");
  }

  docs.push(" {");

  const shouldPrintCloseBracket = shouldCloseBlock(node);
  if (node.children.length > 0) {
    node.firstChild.hasLeadingSpaces = true;
    node.lastChild.hasTrailingSpaces = true;
    docs.push(indent([hardline, printChildren(path, options, print)]));
    if (shouldPrintCloseBracket) {
      docs.push(hardline, "}");
    }
  } else if (shouldPrintCloseBracket) {
    docs.push("}");
  }

  return group(docs, { shouldBreak: true });
}

function shouldCloseBlock(node) {
  return !(
    node.next?.type === "angularControlFlowBlock" &&
    ANGULAR_CONTROL_FLOW_BLOCK_SETTINGS.get(node.name)?.has(node.next.name)
  );
}

function isPreviousBlockUnClosed(path) {
  const { previous } = path;
  return (
    previous?.type === "angularControlFlowBlock" &&
    !hasPrettierIgnore(previous) &&
    !shouldCloseBlock(previous)
  );
}

function printAngularControlFlowBlockParameters(path, options, print) {
  return [
    indent([softline, join([";", line], path.map(print, "children"))]),
    softline,
  ];
}

export { printAngularControlFlowBlock, printAngularControlFlowBlockParameters };
